pub struct PrometheusExporter { /* private fields */ }Expand description
Exports metrics by exposing a Prometheus exporter endpoint.
Implementations
Sourceimpl PrometheusExporter
impl PrometheusExporter
Sourcepub fn new(controller: Controller, addr: SocketAddr) -> Self
pub fn new(controller: Controller, addr: SocketAddr) -> Self
Creates a new PrometheusExporter.
When run/spawned, the exporter will listen at the given socket address, responding to any requests by taking a snapshot and returning it in the text-based Prometheus exposition format.
Sourcepub fn run(self)
pub fn run(self)
Runs the exporter synchronously, blocking the calling thread.
You should run this in a dedicated thread:
let addr = "localhost:9090".parse().expect("failed to parse listen address");
let mut exporter = PrometheusExporter::new(controller, addr);
std::thread::spawn(move || exporter.run());Sourcepub fn into_future(self) -> impl Future<Item = (), Error = HyperError> + Send
pub fn into_future(self) -> impl Future<Item = (), Error = HyperError> + Send
Converts this exporter into a future that runs the Hyper-based exporter endpoint.
let addr = "localhost:9090".parse().expect("failed to parse listen address");
let exporter = PrometheusExporter::new(controller, addr);
let server = exporter.into_future().map_err(|_| ());
tokio::run(server);Auto Trait Implementations
impl Freeze for PrometheusExporter
impl RefUnwindSafe for PrometheusExporter
impl Send for PrometheusExporter
impl Sync for PrometheusExporter
impl Unpin for PrometheusExporter
impl UnsafeUnpin for PrometheusExporter
impl UnwindSafe for PrometheusExporter